aws_appsync_resolver

package module
v0.0.0-...-86ce6f8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2019 License: MIT Imports: 1 Imported by: 0

README

AWS App Sync Resolver

In progress

Just trying to have decent library to deal with App Sync Resolver

Motivations

This work is massively using this repository as source of inspiration.

We needed more functionalities and it did not look like the repo was living a lot.

For example, we needed to wire the context to the handler.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() pipeline.Pipeline

Types

This section is empty.

Directories

Path Synopsis

Jump to